OrchardActions

Trait OrchardActions 

pub trait OrchardActions {
    // Required method
    fn actions(&self) -> impl Iterator<Item = &Action> + '_;
}
A trait for types that can provide Orchard actions.

Required Methods

fn actions(&self) -> impl Iterator<Item = &Action> + '_

Returns an iterator over the actions in this type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors